@@ -42,7 +42,6 @@
 #include "ProgressDialog.h"
 #include "DialogController.h"
 #include "statisticsview.h"
-#include "apikeydialog.h"
 #include "wptabbedlistview.h"
 #include "wpgraphicsview.h"
 #include "enume/pannableview.h"
@@ -67,7 +66,6 @@ BlogView::BlogView()
   , iBlogsView(*this, &BlogView::InitBlogsView)
   , iBlogsGraphicsWidget(*this, &BlogView::InitBlogsView)
   , iPannableBlogWidget(*this, &BlogView::InitBlogsView)
-  , iApiKeyDialog(*this, &BlogView::InitApiKeyDialog)
   , iNetworkEngine(NULL)
   , iCurrentView(1337)         // XXX: this value is arbitrary, since the initial view is undefined
 {
@@ -89,9 +87,6 @@ BlogView::BlogView()
     iThemeData = new ThemeData;
     iThemeData->Init();
     iDialogController = new DialogController(this);
-    
-    // this uses dialog controller
-    connect(iNetworkEngine, SIGNAL(NoAccessPoints()), this, SLOT(ShowNoAccessPointWarning()));
 
     // XXX: remove
     iViewTitle << tr("Edit blog")
@@ -144,6 +139,9 @@ BlogView::BlogView()
         this,     SLOT(ShowTabbedListView())
     );
 
+    // this uses dialog controller
+    connect(iNetworkEngine, SIGNAL(NoAccessPoints()), this, SLOT(ShowNoAccessPointWarning()));
+
     // Progress dialog
     connect(
         iNetworkEngine, SIGNAL(TaskStarted(TWPNetworkEngineCommand)),
@@ -708,11 +706,6 @@ void BlogView::ShowEditBlogView(const QString& aBlogId)
     SwitchView(ESetupBlogView);
 }
 
-int BlogView::ShowApiKeyDialog()
-{
-    return iApiKeyDialog->exec();
-}
-
 void BlogView::OpenStatisticsView ()
 {
     WPDataBlog *blog = iBlogs->GetCurrentBlog();
@@ -720,8 +713,8 @@ void BlogView::OpenStatisticsView ()
     if (!blog)
         return;
 
-    // ensure we have an API key
-    if (blog->HasApiKey()) {
+    // ensure that blog is wordpress.com hosted and we have an API key
+    if (blog->isWordpressHosted() && blog->HasApiKey()) {
         // load data using existing key
         blog->RefreshStats();
 
@@ -729,10 +722,8 @@ void BlogView::OpenStatisticsView ()
         iDialogController->ShowTaskProgress();
 
     } else {
-        // prompt for new key, which will signal SetApiKey() to do the initial request
-        if (ShowApiKeyDialog() != QDialog::Accepted)
-            // cancel
-            return;
+        iDialogController->ShowInfoNote(tr("Statistics"), tr("Statistics are available for wordpress.com hosted blogs only."));
+        return;
     }
 
     // do we have some existing stats to show right away?
@@ -754,18 +745,6 @@ void BlogView::ShowStatisticsView ()
     SwitchView(EStatisticsView);
 }
 
-void BlogView::SetApiKey (const QString &apiKey)
-{
-    if (WPDataBlog *blog = iBlogs->GetCurrentBlog()) {
-        // put key into use
-        if (blog->SetApiKey(apiKey))
-            // show progress for the initial stats request
-            iDialogController->ShowTaskProgress();
-    }
-}
-
-
-
 void BlogView::SaveBlogSetup(WPDataBlog *blog, const WPNetworkEndpoint &settings)
 {
     // show progress for this
@@ -946,7 +925,7 @@ void BlogView::ReplyToComment(WPComment aComment)
 
 void BlogView::Exit()
 {
-    WP_CONFIRM_AND_RETURN_ON_FALSE
+    WP_CONFIRM_AND_RETURN_ON_FALSE(this)
 
     QCoreApplication::exit(0);
 }
@@ -1049,6 +1028,11 @@ void BlogView::InitSetupBlogView()
 {
     iSetupBlogView = new SetupBlog(this);
     iStackedWidget->insertWidget(ESetupBlogView, iSetupBlogView);
+
+    connect(
+            iSetupBlogView, SIGNAL(ErrorNote(QString)),
+            iDialogController, SLOT(ShowErrorNote(QString))
+    );
 }
 
 void BlogView::InitWritePageView()
@@ -1069,6 +1053,14 @@ void BlogView::InitAddPostView()
         iAddPostView, SIGNAL(ShowErrorNote(const QString&)), 
         iDialogController, SLOT(ShowErrorNote(const QString&))
     );
+    connect(
+        iAddPostView, SIGNAL(ResolveFormattedAddress(qreal, qreal)),
+        iNetworkEngine, SLOT(GetLocationAddress(qreal,qreal))
+    );
+    connect(
+        iNetworkEngine, SIGNAL(FormattedAddressGotten(qreal,qreal,QString)),
+        iAddPostView, SLOT(FormattedAddressResolved(qreal,qreal,QString))
+    );
 }
 
 void BlogView::InitSinglePostView()
@@ -1124,15 +1116,6 @@ void BlogView::InitStatisticsView()
         iStatisticsView->updateStats(iBlogs->GetCurrentBlog()->iStats);
 }
 
-void BlogView::InitApiKeyDialog()
-{
-    iApiKeyDialog = new ApiKeyDialog();
-    connect(
-            iApiKeyDialog, SIGNAL(textComplete(const QString&)), 
-            this, SLOT(SetApiKey(const QString&))
-    );
-}
-
 void BlogView::InitBlogsView()
 {
     iBlogsView = new WPGraphicsView(this);
