@@ -1,12 +1,15 @@
 #ifndef LOCATIONBUTTON_H_
 #define LOCATIONBUTTON_H_
 
+#include <QDateTime>
 #include <QPushButton>
 #if defined(HAVE_QTM_LOCATION)
-#include <QGeoCoordinate>
+#include <QGeoPositionInfo>
 #endif // defined(HAVE_QTM_LOCATION)
 
 class QResizeEvent;
+class QTimer;
+class QIcon;
 
 class LocationButton : public QPushButton
     {
@@ -14,13 +17,19 @@ class LocationButton : public QPushButton
     
 public:
     LocationButton(QWidget * parent = 0);
+    virtual ~LocationButton();
     
-    void resetCoordinate();
+    void resetPosition();
     void setNotSupported();
+    void setBusy(bool busy);
+    void setFormattedAddress(const QString& address);
 #if defined(HAVE_QTM_LOCATION)
-    void setCoordinate(QtMobility::QGeoCoordinate const & newCoordinate);
+    void setPosition(QtMobility::QGeoPositionInfo const & newPosition);
 #endif // defined(HAVE_QTM_LOCATION)
     
+private slots:
+    void timerTimeout();
+
 protected:
     // make protected
     void setText(const QString & str) { QPushButton::setText(str); } 
@@ -31,11 +40,17 @@ protected:
 private:
     void updateText();
     int getTextWidth();
+    QString formatTimeSince(const QDateTime &t);
     
 private:
     bool supported;
+    QTimer* timer;
+    QIcon *icons;
+    int iconIndex;
+
+    QString formattedAddress;
 #if defined(HAVE_QTM_LOCATION)
-    QtMobility::QGeoCoordinate coordinate;
+    QtMobility::QGeoPositionInfo position;
 #endif // defined(HAVE_QTM_LOCATION)
     };
 
