@@ -270,14 +270,23 @@ void WPDataUsersBlogs::BlogsListed (WPNetworkEndpoint endpoint, QList<WPXmlItem>
     // this is ONLY called after NewBlog, and NewBlog will always deactivate the current blog
     Q_ASSERT(!iActiveBlog);
 
-    // pick the first newly added blog as active
-    if (iBlogs.size() > oldBlogs)
-        // this does the SetEndpoint() with the full NetworkEndpoint info that we have now
-        ActivateBlog(iBlogs[oldBlogs]);
-
-    else if (iBlogs.size() > 0)
-        // XXX: no new blogs, which one now?
-        ActivateBlog(iBlogs[0]);
+    // Try to find the blog the user wanted to activate from the new blogs
+    for(int i = oldBlogs; i < iBlogs.count(); ++i) {
+        if(iBlogs[i]->iEndpoint.iBlogUrl.contains(endpoint.iBlogUrl, Qt::CaseInsensitive)) {
+            ActivateBlog(iBlogs[i]);
+            break;
+        }
+    }
+    
+    // If the above failed, fall back to something else
+    if(!iActiveBlog) {
+        // pick the first newly added blog as active
+        if (iBlogs.size() > oldBlogs)
+            ActivateBlog(iBlogs[oldBlogs]);
+        else if (iBlogs.size() > 0)
+            // XXX: no new blogs, which one now?
+            ActivateBlog(iBlogs[0]);
+    }
 
     // blog discovery was succesfull, UI can continue
     emit GetUserBlogsCompleted(*iActiveBlog);
@@ -297,11 +306,11 @@ void WPDataUsersBlogs::BlogApiKeyUpdated (WPDataBlog *blog, QString apiKey)
     endpoint.iApiKey = apiKey;
 
     // update engine to temporarily use this api key
-    emit SetEndpoint(endpoint);
+    //emit SetEndpoint(endpoint);
 
     // reload stats using new api key
     // if this succeeds, the new api key is stored in our iendpoint
-    blog->RefreshStats();
+    //blog->RefreshStats();
 }
 
 void WPDataUsersBlogs::ActivateBlog (WPDataBlog *blog)
@@ -456,6 +465,10 @@ void WPDataUsersBlogs::ActivateBlog (WPDataBlog *blog)
         engine,       SIGNAL(CategoriesListed (QList<WPXmlItem>)),
         blog,           SLOT(CategoriesListed (QList<WPXmlItem>))
     );
+    connect(
+        engine,       SIGNAL(ApiKeyReceived(QString)),
+        blog,           SLOT(SetApiKey(QString))
+    );
 
     // gotten
     connect(
@@ -718,8 +731,9 @@ bool WPDataBlog::SetApiKey (const QString &apiKey) {
         // nothing
         return false;
 
+    iEndpoint.iApiKey = apiKey;
     // test it, by temporarily setting it on the networkengine
-    emit ApiKeyChanged(this, apiKey);
+    //emit ApiKeyChanged(this, apiKey);
 
     // changed
     return true; 
@@ -736,11 +750,17 @@ void WPDataBlog::GetStatsSucceeded (QString blogUrl, QString apiKey)
     iEndpoint.iApiKey = apiKey;
 }
 
-bool WPDataBlog::HasApiKey () {
+bool WPDataBlog::isWordpressHosted() const
+{
+    return iEndpoint.isWordpressHosted();
+}
+
+bool WPDataBlog::HasApiKey () const
+{
     return !iEndpoint.iApiKey.isEmpty();
 }
     
-bool WPDataBlog::HasStatsData ()
+bool WPDataBlog::HasStatsData () const
 {
     return iStats.iLastUpdated.isValid();
 }
@@ -766,7 +786,7 @@ void WPDataBlog::RefreshAll ()
 
 void WPDataBlog::RefreshStats ()
 {
-    int days = 365;
+    int days = 366;
 
     if (!iStats.iLastUpdated.isNull())
         // days since last update
