@@ -725,26 +725,17 @@ public:
      */
     QListIterator<WPComment> GetComments () const;
 
-    /**
-     * Set the statistics API key to use for this blog.
-     *
-     * If the given api key is the same as the current one, nothing happens.
-     *
-     * Otherwise, we tell the NetworkEngine to refresh the stats using the new API key, and if that
-     * refresh succeeds, we store the new API key in our iEndpoint, which is then then used again
-     * next time.
-     */
-    bool SetApiKey (const QString &apiKey);
+    bool isWordpressHosted() const;
 
     /**
      * Do we have a persistent API key configured?
      *
      * XXX: if we're still waiting between SetApiKey() and GetStatsSucceeded(), this will return false.
      */
-    bool HasApiKey ();
+    bool HasApiKey () const;
 
     /** Do we have some existing stats data avilable? */
-    bool HasStatsData ();
+    bool HasStatsData () const;
 
     /**
      * Refresh all pages/posts/comments and aux. data.
@@ -770,7 +761,7 @@ signals: /* -> Network */
     void GetPostStatuses ();
     void GetCommentStatuses ();
     void GetStats (QString table, int days);
-    
+
     /** Create new category, resulting in CategoryCreated with categoryId */
     void NewCategory (int localId, WPXmlItem xml);
     
@@ -778,7 +769,6 @@ signals: /* -> Network */
     void ApiKeyChanged (WPDataBlog *blog, QString apiKey);
 
 public slots: /* Network -> */
-
     /**
      * Update iCategories list from category list.
      *
@@ -794,6 +784,17 @@ public slots: /* Network -> */
     /** API key is valid */
     void GetStatsSucceeded (QString blogUrl, QString apiKey);
 
+    /**
+     * Set the statistics API key to use for this blog.
+     *
+     * If the given api key is the same as the current one, nothing happens.
+     *
+     * Otherwise, we tell the NetworkEngine to refresh the stats using the new API key, and if that
+     * refresh succeeds, we store the new API key in our iEndpoint, which is then then used again
+     * next time.
+     */
+    bool SetApiKey (const QString &apiKey);
+
 signals: /* -> UI */
 
     void PageAdded (WPPage page);
