@@ -6,13 +6,13 @@
  */
 
 #include <QtGlobal>
+#include <QAuthenticator>
 #include <QBuffer>
 #include <QDebug>
 #include <QNetworkReply>
 #include <QStringList>
 #include <QTreeWidget>
 #include <QListWidgetItem>
-#include <QMessageBox>
 #include <QDesktopServices>
 #include <QTime>
 #include <QByteArray>
@@ -27,6 +27,7 @@
 #include "WPNetworkEngine.h"
 #include "WPXmlRsdParser.h"
 #include "WPXmlStatsParser.h"
+#include "WPXmlApiKeyParser.h"
 #include "WPXmlRequest.h"
 #include "WPXmlResponse.h"
 #include "WPData.h"
@@ -60,8 +61,13 @@ WPNetworkEngine::WPNetworkEngine()
     );
 
     connect(
-        iNetworkAccessManager, SIGNAL(sslErrors (QNetworkReply *, const QList<QSslError> &)),
-        this, SLOT(HandleSslErrors (QNetworkReply *, const QList<QSslError> &))
+        iNetworkAccessManager, SIGNAL(sslErrors(QNetworkReply *, QList<QSslError>)),
+        this, SLOT(HandleSslErrors(QNetworkReply *, QList<QSslError>))
+    );
+
+    connect(
+        iNetworkAccessManager, SIGNAL(authenticationRequired(QNetworkReply*,QAuthenticator*)),
+        this, SLOT(HandleAuthentication(QNetworkReply*,QAuthenticator*))
     );
     
     OpenNetworkSession();
@@ -90,6 +96,9 @@ void WPNetworkEngine::SetEndpoint (WPNetworkEndpoint endpoint)
     // store, replacing old endpoint
     // this endpoint should contain all required info (iBlogId, iUsername, iPassword)
     iEndpoint = endpoint;
+
+    if (endpoint.isWordpressHosted() && endpoint.iApiKey.isEmpty())
+        GetApiKey();
 }
     
 void WPNetworkEngine::DiscoverEndpoint (WPNetworkEndpoint endpoint)
@@ -392,12 +401,26 @@ void WPNetworkEngine::GetStats (QString table, int days) {
     if (!table.isEmpty())
         url.addQueryItem("table", table);
 
-    url.addQueryItem("days", QString::number(days));
+    url.addQueryItem("days", QString::number(days)); // last n days
+    url.addQueryItem("limit", "-1"); // -1 means unlimited records
 
     // do GET
     ExecuteRequest(url, EGetStats, 0);
 }
 
+void WPNetworkEngine::GetApiKey()
+{
+    ExecuteRequest(QUrl("https://public-api.wordpress.com/getuserblogs.php"), EFetchingApiKey, 0);
+}
+
+void WPNetworkEngine::GetLocationAddress(qreal latitude, qreal longitude)
+{
+    QUrl url("http://maps.googleapis.com/maps/api/geocode/xml");
+    url.addQueryItem("latlng", QString("%1,%2").arg(latitude).arg(longitude));
+    url.addQueryItem("sensor", "false");
+    ExecuteRequest(url, EFetchingLocation, 0);
+}
+
 void WPNetworkEngine::HandleSslErrors (QNetworkReply *reply, const QList<QSslError> &errors)
 {
     qWarning() << "WPNetworkEngine::HandleSslErrors - " << reply->url().toString();
@@ -624,6 +647,34 @@ void WPNetworkEngine::HandleNetworkReply (QNetworkReply *networkReply)
         }
     } break;
 
+    case EFetchingApiKey: {
+        WPXmlApiKeyParser parser(networkReply->readAll());
+
+        parser.ParseResponse();
+        if (parser.hasError()) {
+            HandleNetworkError(networkReply, item, command, tr("Couldn't parse api key"));
+        } else {
+            iEndpoint.iApiKey = parser.GetApiKey();
+            emit ApiKeyReceived(iEndpoint.iApiKey);
+            emit TaskFinished(command);
+        }
+    } break;
+
+    case EFetchingLocation: {
+        QRegExp pattern("<formatted_address>([^<]+)</formatted_address>");
+        if (pattern.indexIn(QString::fromUtf8(networkReply->readAll())) > -1) {
+            QString latlng = networkReply->request().url().queryItemValue("latlng");
+            int pos = latlng.indexOf(",");
+            QString lat = latlng.mid(0, pos);
+            QString lng = latlng.mid(pos + 1);
+            QString formattedAddress = pattern.cap(1).trimmed();
+            emit FormattedAddressGotten(lat.toDouble(), lng.toDouble(), formattedAddress);
+            emit TaskFinished(EFetchingLocation);
+        } else {
+            HandleNetworkError(networkReply, item, command, tr("Couldn't parse formatted address from location response."));
+        }
+    } break;
+
     case EGetRSD:
     {
         QList<WPDataRsdApi> rsdEndpoints;
@@ -632,7 +683,8 @@ void WPNetworkEngine::HandleNetworkReply (QNetworkReply *networkReply)
         if (!rsdEndpoints.isEmpty()) {
             // follow first one
             // XXX: bad, the RSD also has e.g. the Atom endpoint
-            GetUsersBlogs(QUrl::fromUserInput(rsdEndpoints[0].iApiLink));
+            QUrl apiUrl = QUrl::fromUserInput(rsdEndpoints[0].iApiLink);
+            GetUsersBlogs(apiUrl);
 
             emit TaskFinished(command);
 
@@ -681,7 +733,8 @@ void WPNetworkEngine::HandleNetworkReply (QNetworkReply *networkReply)
         }
         else if (networkReply->hasRawHeader("X-Pingback")) // If no rsd url found, using http header
         {
-            GetUsersBlogs(QString::fromAscii(networkReply->rawHeader("X-Pingback")));
+            QString pingbackUrl = QString::fromAscii(networkReply->rawHeader("X-Pingback"));
+            GetUsersBlogs(pingbackUrl);
         }
         else
         {
@@ -715,6 +768,30 @@ void WPNetworkEngine::HandleNetworkReply (QNetworkReply *networkReply)
     // finally, cleanup   
     networkReply->deleteLater();
 }
+
+void WPNetworkEngine::HandleAuthentication(QNetworkReply *networkReply, QAuthenticator *authenticator)
+{
+    qDebug("HandleAuthentication");
+
+    // Lookup command type
+    TWPNetworkEngineCommand command;
+
+    bool success;
+    QVariant typeVariant = networkReply->request().attribute(QNetworkRequest::Attribute(QNetworkRequest::User + 1));
+
+    command = (TWPNetworkEngineCommand) typeVariant.toInt(&success);
+
+    if (!success) {
+        qWarning("Unable to authenticate request because network engine command argument is missing");
+        return;
+    }
+
+    if (command == EFetchingApiKey) {
+        qDebug("Authenticating api key request");
+        authenticator->setUser(iEndpoint.iUsername);
+        authenticator->setPassword(iEndpoint.iPassword);
+    }
+}
     
 QString WPNetworkEngine::NetworkReplyToError (QNetworkReply *networkReply)
 {
@@ -762,6 +839,7 @@ QString WPNetworkEngine::NetworkReplyToError (QNetworkReply *networkReply)
         case QNetworkReply::UnknownContentError:
         case QNetworkReply::ProtocolFailure:
         default:
+            qDebug() << "Error code:" << networkReply->error();
             return tr("Connection error: ") + networkReply->errorString();
     }
 }
@@ -1583,6 +1661,7 @@ bool WPNetworkEngine::QueueRequestIfNecessary(const QUrl &url, TWPNetworkEngineC
     return true;
     
 #else // HAVE_QTMOBILITY
+    Q_UNUSED(url); Q_UNUSED(cmd); Q_UNUSED(id); Q_UNUSED(body); Q_UNUSED(contentType);
     return false; // Never queue
 #endif // HAVE_QTMOBILITY
 }
