@@ -397,7 +397,6 @@ bool PannableViewPrivate::endReached()
     bool checkHeight = limitRect.height() >= viewHeight;
 
     if ( !limitRect.contains( viewRect )){
-
         QRectF intersection = limitRect.intersected( viewRect );
         QList<QPointF> points;
         points << pos;
@@ -455,7 +454,15 @@ bool PannableViewPrivate::endReached()
             return true;
         }
 
-
+        /* Handling items smaller than the view added
+         * by aahv on 2010-10-20
+         */
+        if (limitRect.height() < viewHeight) {
+            stopScrolling();
+            points << QPointF( widgetX, m_minY);
+            animateEnd(points);
+            return true;
+        }
     }
 
     return false;
