@@ -34,6 +34,9 @@ protected:
 private:
     Ui::RichTextEdit *ui;
 
+signals:
+    void showErrorNote(const QString& aError);
+
 private slots:
     void on_boldButton_toggled(bool checked);
     void on_italicButton_toggled(bool checked);
