@@ -30,6 +30,9 @@ public:
     void NewBlog();
     void EditBlog(WPDataBlog* aBlog);
     
+signals:
+    void ErrorNote(const QString &message);
+
 public slots:
     void Save();
     void setFocus();
