@@ -19,9 +19,9 @@
 #include "statsweeklydata.h"
 #include "statsmonthlydata.h"
 
-namespace Ui {
-    class StatsVisits;
-}
+class QButtonGroup;
+class QGridLayout;
+class QLabel;
 
 class StatsVisits : public QWidget {
     Q_OBJECT
@@ -32,17 +32,22 @@ public:
 public slots:
     void updateStats(const WPDataStats& stats);
 
-protected:
-    void changeEvent(QEvent *e);
-
 private slots:
-    void buttonClicked(QAbstractButton* button);
+    void buttonClicked(int id);
+
+protected:
+    void resizeEvent(QResizeEvent *);
 
 private:
+    void updateLayout();
     void switchPlotData(LinePlotData* data);
 
 private:
-    Ui::StatsVisits *ui;
+    QLabel* label;
+    QAbstractButton *dayButton;
+    QAbstractButton *weekButton;
+    QAbstractButton *monthButton;
+    QButtonGroup *viewButtonGroup;
     LinePlot* plot;
 
     StatsDailyData* dailyData;
